# RegressionInC

A package focussing on regression for complex-valued variables

## Terminology

y = X * coef

- y are called the observations
- X are the predictors
- coef are the coefficients

Other formulations and terminology include

### Fitting

When fitting the linear problem, the aim is to:

- Find the coefficients, coef, given observations y and predictors X

### Predicting

When predicting the linear problem, the aim is to:

- Calculate new observations, y, given predictors X and coefficients coef